@@ -10,8 +10,8 @@ intsvy.log.pv <-
     #  JK with weight variables
     if (config$parameters$weights == "JK with weights") {
     
-      pvnames <- paste0("^", config$variables$pvlabelpref, "*[0-9].*", pvnames)
-      pvnames <- grep(pvnames, names(data), value = TRUE)
+      #pvnames <- paste0("^", config$variables$pvlabelpref, "*[0-9].*", pvnames)
+      #pvnames <- grep(pvnames, names(data), value = TRUE)
       weights <- grep(paste0("^", config$variables$weightJK , ".*[0-9]+$"), 
                       names(data), value = TRUE)
       
@@ -86,8 +86,8 @@ intsvy.log.pv <-
       # Replicate weighted %s (sampling error)
       # in PISA
       
-      pvnames <- paste0(pvnames, ".*[0-9]|[0-9].*", pvnames)
-      pvnames <- grep(pvnames, names(data), value = TRUE)
+      #pvnames <- paste0(pvnames, ".*[0-9]|[0-9].*", pvnames)
+      #pvnames <- grep(pvnames, names(data), value = TRUE)
       weights <- grep(paste0("^", config$variables$weightBRR , ".*[0-9]+$"), 
                       names(data), value = TRUE)
       
@@ -151,7 +151,7 @@ intsvy.log.pv <-
       # jack knife
       # in PIRLS / TIMSS
       
-      pvnames <- grep(pvnames, names(data), value = TRUE)
+      #pvnames <- grep(pvnames, names(data), value = TRUE)
       
       # Dependent binary variable
       di <- as.data.frame(sapply(pvnames, function(pv) ifelse(data[[pv]] > cutoff, 1, 0)))
