@@ -1,7 +1,7 @@
 piaac.ben.pv <- 
 function(pvlabel, by, data, cutoff=cutoff, atlevel=FALSE, export=FALSE, 
          name= "output", folder=getwd()) {
-  intsvy.ben.pv(pvnames = paste("PV", pvlabel, 1:10, sep=""), by=by, cutoff=cutoff, data=data, 
+  intsvy.ben.pv(pvnames=pvlabel, by=by, cutoff=cutoff, data=data, 
                 atlevel=atlevel, export=export, name= name, folder=folder,
                 config=piaac_conf)
 
