@@ -1,4 +1,4 @@
-pisa.per.pv <-  function(pvlabel="READ", by, per, data, export=FALSE, name= "output", folder=getwd()) {
+pisa.per.pv <-  function(pvlabel, by, per, data, export=FALSE, name= "output", folder=getwd()) {
     
     intsvy.per.pv(pvnames = pvlabel, by=by, per=per, data=data, export=export, 
                   name= name, folder=folder, config=pisa_conf)
